# Movable Type plugin.
#
# Release 0.01 (Jan 05, 2009) initial version.
#
# Copyright (c) 2004-2009 Yujiro Araki

package MT::Plugin::BlogIDViewer;
use strict;
use base qw(MT::Plugin);

use MT;
use MT::Blog;

our $VERSION = '0.01';

my $plugin = __PACKAGE__->new({
    id => 'blog_id_viewer',
    name => 'BlogIDViewer',
    description => '<MT_TRANS phrase="Display Blog ID.">',
    doc_link => 'http://www.koikikukan.com/archives/2009/01/05-005555.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    l10n_class => 'BlogIDViewer::L10N',
    version => $VERSION,
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'MT::App::CMS::template_source.header'
                => \&display_blog_id_header,
            'MT::App::CMS::template_source.blog_table'
                => \&display_blog_id_blog_table,
        },
   });
}

sub display_blog_id_header {
    my ($cb, $app, $template) = @_;

    my $old = <<HERE;
                            <li><a href="<\$mt:var name="mt_url"\$>?blog_id=<\$mt:var name="top_blog_id"\$>&amp;<\$mt:var name="return_args" escape="html"\$>"><\$mt:var name="top_blog_name" escape="html"\$></a></li>
HERE
    $old = quotemeta($old);

    my $new = <<HERE;
                            <li><a href="<\$mt:var name="mt_url"\$>?blog_id=<\$mt:var name="top_blog_id"\$>&amp;<\$mt:var name="return_args" escape="html"\$>"><\$mt:var name="top_blog_id" escape="html"\$>:<\$mt:var name="top_blog_name" escape="html"\$></a></li>
HERE
    $$template =~ s/$old/$new/;

    $old = <<HERE;
                        <a href="javascript:void(0);" id="current-blog-title" mt:command="open-menu"><mt:if name="blog_id"><\$mt:var name="blog_name" escape="html"\$><mt:else><em><__trans phrase="System Overview"></em></mt:if><span>&nbsp;</span></a>
HERE
    $old = quotemeta($old);

    $new = <<HERE;
                        <a href="javascript:void(0);" id="current-blog-title" mt:command="open-menu"><mt:if name="blog_id"><\$mt:var name="blog_id" escape="html"\$>:<\$mt:var name="blog_name" escape="html"\$><mt:else><em><__trans phrase="System Overview"></em></mt:if><span>&nbsp;</span></a>
HERE
    $$template =~ s/$old/$new/;
}

sub display_blog_id_blog_table {
    my ($cb, $app, $template) = @_;

    my $old = <<HERE;
            <th id="bt-name"><__trans phrase="Blog Name"></th>
HERE
    $old = quotemeta($old);

    my $new = <<HERE;
            <th id="bt-id"><__trans phrase="Blog ID"></th>
            <th id="bt-name"><__trans phrase="Blog Name"></th>
HERE
    $$template =~ s/$old/$new/;

    $old = <<HERE;
            <td><a href="?__mode=dashboard&amp;blog_id=<mt:var name="id">"><mt:var name="name" escape="html"></a></td>
HERE
    $old = quotemeta($old);

    $new = <<HERE;
            <td><mt:var name="id"></td>
            <td><a href="?__mode=dashboard&amp;blog_id=<mt:var name="id">"><mt:var name="name" escape="html"></a></td>
HERE
    $$template =~ s/$old/$new/;
}

1;
